**Example 1: 删除交互式session（notebook）**

删除交互式session（notebook）

Input: 

```
tccli dlc DeleteNotebookSession --cli-unfold-argument  \
    --SessionId d3018ad4-9a7e-4f64-a3f4-f38507c69742
```

Output: 
```
{
    "Response": {
        "RequestId": "b8sd7dd7-ekd4-4e5e-993e-e5db64fa21c1"
    }
}
```

